cachestorage

package
v0.0.0-...-7af6ec4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 23, 2017 License: Unlicense Imports: 2 Imported by: 0

Documentation

Overview

Package cachestorage provides commands and events for CacheStorage domain.

Index

Constants

const (
	RequestCacheNames     = "CacheStorage.requestCacheNames"
	RequestEntries        = "CacheStorage.requestEntries"
	DeleteCache           = "CacheStorage.deleteCache"
	DeleteEntry           = "CacheStorage.deleteEntry"
	RequestCachedResponse = "CacheStorage.requestCachedResponse"
)

List of commands in CacheStorage domain

Variables

This section is empty.

Functions

This section is empty.

Types

type CacheStorage

type CacheStorage struct {
	// contains filtered or unexported fields
}

func New

func New(conn cri.Connector) *CacheStorage

New creates a CacheStorage instance

func (*CacheStorage) DeleteCache

func (obj *CacheStorage) DeleteCache(request *DeleteCacheRequest) (err error)

Deletes a cache.

func (*CacheStorage) DeleteEntry

func (obj *CacheStorage) DeleteEntry(request *DeleteEntryRequest) (err error)

Deletes a cache entry.

func (*CacheStorage) RequestCacheNames

func (obj *CacheStorage) RequestCacheNames(request *RequestCacheNamesRequest) (response RequestCacheNamesResponse, err error)

Requests cache names.

func (*CacheStorage) RequestCachedResponse

func (obj *CacheStorage) RequestCachedResponse(request *RequestCachedResponseRequest) (response RequestCachedResponseResponse, err error)

Fetches cache entry.

func (*CacheStorage) RequestEntries

func (obj *CacheStorage) RequestEntries(request *RequestEntriesRequest) (response RequestEntriesResponse, err error)

Requests data from cache.

type DeleteCacheRequest

type DeleteCacheRequest struct {
	// Id of cache for deletion.
	CacheId types.CacheStorage_CacheId `json:"cacheId"`
}

type DeleteEntryRequest

type DeleteEntryRequest struct {
	// Id of cache where the entry will be deleted.
	CacheId types.CacheStorage_CacheId `json:"cacheId"`
	// URL spec of the request.
	Request string `json:"request"`
}

type RequestCacheNamesRequest

type RequestCacheNamesRequest struct {
	// Security origin.
	SecurityOrigin string `json:"securityOrigin"`
}

type RequestCacheNamesResponse

type RequestCacheNamesResponse struct {
	// Caches for the security origin.
	Caches []types.CacheStorage_Cache `json:"caches"`
}

type RequestCachedResponseRequest

type RequestCachedResponseRequest struct {
	// Id of cache that contains the enty.
	CacheId types.CacheStorage_CacheId `json:"cacheId"`
	// URL spec of the request.
	RequestURL string `json:"requestURL"`
}

type RequestCachedResponseResponse

type RequestCachedResponseResponse struct {
	// Response read from the cache.
	Response types.CacheStorage_CachedResponse `json:"response"`
}

type RequestEntriesRequest

type RequestEntriesRequest struct {
	// ID of cache to get entries from.
	CacheId types.CacheStorage_CacheId `json:"cacheId"`
	// Number of records to skip.
	SkipCount int `json:"skipCount"`
	// Number of records to fetch.
	PageSize int `json:"pageSize"`
}

type RequestEntriesResponse

type RequestEntriesResponse struct {
	// Array of object store data entries.
	CacheDataEntries []types.CacheStorage_DataEntry `json:"cacheDataEntries"`
	// If true, there are more entries to fetch in the given range.
	HasMore bool `json:"hasMore"`
}

Jump to